@@ -136,3 +136,9 @@ class AmoSession(requests.Session):
             req = super().request('get', redirect_url, params=redirdata, allow_redirects=False)
 
         return req.status_code == 302
+
+    def get_amo_cookie(self, name):
+        for cookie in self.cookies:
+            if cookie.domain.endswith(".addons.mozilla.org") and cookie.name == name:
+                return cookie.value
+        return None
